{% extends 'space_base.html' %}
{% load staticfiles %}

{% block main %}

  <div class="row">
    {% if cluster %}
    <div class="col-md-12">
      <iframe id="iframe1" src="{{pipeline_url}}" style="width: 100%; height: 1500px;border-width: 0px;">        
      </iframe>

     </div>
            
  <script type="text/javascript">
    var height1 = $(window).height() - 80;
    $("body").css("overflow-y","hidden");
    $("#iframe1").height(height1);
    $("div.animated").css("padding","0px");
    
    // linsten window size change event
    $(window).resize(function() { 
       var height1 = $(this).height() - 80; 
     $("#iframe1").height(height1);
    });
  </script>


    {% endif %}
  </div>

{% endblock %}
