{% extends 'site_base_iframe.html' %}
{% load staticfiles %}


{% block sidebar-nav %}
            <li class="nav-title">Space</li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_cluster_info' cluster.id %}">
                <i class="nav-icon icon-speedometer"></i> Dashboard
              </a>
            </li>

            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_cluster_instance_list' cluster.id %}">
                <i class="nav-icon fa fa-cubes"></i> Hosts
              </a>
            </li>

            <li class="nav-title">DATA</li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_dataset_list' cluster.id %}">
                <i class="nav-icon fa fa-tasks"></i> Datasets</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_data_instance_list' cluster.id %}">
                <i class="nav-icon fa fa-hdd-o"></i> Data Instances</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_data_pipeline' cluster.id %}">
                <i class="nav-icon fa fa-random"></i> Data Pipeline</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_notebook' cluster.id %}">
                <i class="nav-icon fa fa-pencil-square-o"></i> Notebook</a>
            </li>

            <li class="nav-title">ADMIN</li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_op_list' cluster.id %}">
                <i class="nav-icon fa fa-sort-amount-desc"></i> SciSpace Operations</a>
            </li>
            <li class="nav-item">
              <a class="nav-link" href="{% url 'scispace_datainstance_op_list' cluster.id %}">
                <i class="nav-icon fa fa-sort-amount-desc"></i> Instance Operations</a>
            </li>
            <li class="nav-item">
              {% if not cluster.portal %}
              <a class="nav-link" href="#" onclick="javascript:alert('Cluster Manage is Unavailable!');" target="_blank">
                <i class="nav-icon fa fa-gears"></i> Cluster Manage</a>
              {% else %}
              <a class="nav-link" href="{{cluster.portal | default_if_none:'#'}}" target="_blank">
                <i class="nav-icon fa fa-gears"></i> Cluster Manage</a>
              {% endif %}
            </li>

            
{% endblock %}
